﻿using Microsoft.AspNetCore.Components;
using MudBlazor;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Threading.Tasks;
using WF_WebAdmin.Model;
using WF_WebAdmin.Service;

namespace WF_WebAdmin.Pages
{
    public partial class CommentaryChart : ComponentBase
    {
        [Inject] public ICommentaryService CommentaryService { get; set; } = default!;

        public List<string> Labels { get; set; } = new(); 
        public List<double[]> ChartData { get; set; } = new();  
        public List<int> AvailableYears { get; set; } = new();  
        public int SelectedYear { get; set; }  

        private List<Commentary> AllComments = new();

        protected override async Task OnInitializedAsync()
        {
            // Charger tous les commentaires
            AllComments = await CommentaryService.GetCommentsAsync();

            if (!AllComments.Any())
            {
                Labels = new List<string> { "Aucun commentaire" };
                ChartData = new List<double[]> { new double[] { 0 } };
                return;
            }

            AvailableYears = AllComments
                .Select(c => c.DateCreation.Year)
                .Distinct()
                .OrderBy(y => y)
                .ToList();

            SelectedYear = AvailableYears.Max();

            UpdateChartData(SelectedYear);
        }

        private void UpdateChartData(int newYear)
        {
            SelectedYear = newYear;

            var filteredComments = AllComments
                .Where(c => c.DateCreation.Year == SelectedYear)
                .ToList();

            if (!filteredComments.Any())
            {
                Labels = new List<string> { "Aucun commentaire" };
                ChartData = new List<double[]> { new double[] { 0 } };
                return;
            }

            var grouped = Enumerable.Range(1, 12)
                .ToDictionary(
                    month => new DateTime(SelectedYear, month, 1).ToString("MMMM", CultureInfo.InvariantCulture),
                    month => filteredComments.Count(c => c.DateCreation.Month == month)
                );

            Labels = grouped.Keys.ToList();
            ChartData = new List<double[]> { grouped.Values.Select(v => (double)v).ToArray() };
        }
    }
}
