﻿using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.RazorPages;
using System.Diagnostics;

namespace WF_WebAdmin.Pages
{
    [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
    [IgnoreAntiforgeryToken]
    public class ErrorModel : PageModel
    {
        public string? RequestId { get; set; }

        public bool ShowRequestId => !string.IsNullOrEmpty(RequestId);

        private readonly ILogger<ErrorModel> _logger;


        /// <summary>
        /// Initializes a new instance of the <see cref="ErrorModel"/> class.
        /// This constructor is used to inject the <see cref="ILogger{ErrorModel}"/> into the model for logging purposes.
        /// </summary>
        /// <param name="logger">An instance of the <see cref="ILogger{ErrorModel}"/> used for logging error-related information.</param>
        public ErrorModel(ILogger<ErrorModel> logger)
        {
            _logger = logger;
        }


        /// <summary>
        /// Handles the GET request for the page or endpoint.
        /// This method retrieves the request ID for tracing purposes, using the `Activity.Current?.Id` 
        /// if it's available, or the `HttpContext.TraceIdentifier` as a fallback if no current activity ID is present.
        /// </summary>
        public void OnGet()
        {
            // Retrieve the current request ID for tracing
            RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier;
        }
    }
}
