﻿using Microsoft.AspNetCore.Components;
using Microsoft.Extensions.Configuration.UserSecrets;
using Microsoft.Extensions.Localization;
using WF_WebAdmin.Model;



namespace WF_WebAdmin.Pages
{
    public partial class Login
    {
        [Inject]
        public IStringLocalizer<Login> Localizer { get; set; }

        private UserLogin userLogin = new UserLogin();

        [Inject]
        public UserLogin uLogin { get; set; }

        private string ErrorConnexion;

        private List<UserLogin> usersConnexion;
        [Inject]
        public HttpClient Http { get; set; }

        [Inject]
        public NavigationManager NavigationManager { get; set; }


        /// <summary>
        /// Asynchronously initializes the component by loading user login data.
        /// This method retrieves a list of user login information from a JSON file located at the specified URI 
        /// and populates the `usersConnexion` list with the data.
        /// </summary>
        protected override async Task OnInitializedAsync()
        {
            // Fetch user login data from the specified JSON file.
            usersConnexion = await Http.GetFromJsonAsync<List<UserLogin>>($"{NavigationManager.BaseUri}fake-dataUserLogin.json");
        }


        /// <summary>
        /// Validates the login credentials of the user.
        /// This method checks if the provided username and password match any user in the `usersConnexion` list.
        /// If the credentials are correct and the user is an admin, it stores the user details and navigates to the home page.
        /// If the credentials are incorrect, an error message is set for display.
        /// </summary>
        public void validlogin()
        {
            // Check if both the username and password are provided
            if (!string.IsNullOrEmpty(userLogin.Name) || !string.IsNullOrEmpty(userLogin.Mdp))
            {
                // Loop through the list of connected users to find a match
                foreach (var user in usersConnexion)
                {
                    // Check if the username and password match the user credentials
                    if (userLogin.Name == user.Name && userLogin.Mdp == user.Mdp)
                    {
                        // Check if the user is an admin
                        if (user.IsAdmin)
                        {
                            // If the user is an admin, store their information and navigate to the home page
                            uLogin.Id = userLogin.Id;
                            uLogin.Name = user.Name;
                            uLogin.Image = user.Image;

                            // Redirect to the homepage
                            NavigationManager.NavigateTo(NavigationManager.BaseUri + "accueil");
                            return;

                        }
                        else
                        {
                            // If the user is not an admin, display an error message
                            ErrorConnexion = "Connexion échouée, le nom ou le mot de passe sont incorrectes";
                        }

                    }
                    else
                    {
                        // If credentials do not match, set the error message
                        ErrorConnexion = "Connexion échouée, le nom ou le mot de passe sont incorrectes";
                    }
                }
            }
        }
    }
}