﻿using Microsoft.AspNetCore.Mvc.RazorPages;
using System.Text.Json;
using WF_WebAdmin.Model;

namespace WF_WebAdmin.Service
{
    public class LogsServiceStub : ILogsService
    {
        private readonly string _jsonFilePath = Path.Combine(Environment.CurrentDirectory, "wwwroot", "fake_data_logs.json");

        public async Task saveLogsJson(List<Logs> logs)
        {
            var json = JsonSerializer.Serialize(logs, new JsonSerializerOptions { WriteIndented = true });
            await File.WriteAllTextAsync(_jsonFilePath, json);
        }


        public async Task addLogs(Logs logs)
        {
            var data = await getAllLogs();

            data.Add(logs);
            await saveLogsJson(data);
        }


        public async Task<List<Logs>> getAllLogs()
        {
            if (!File.Exists(_jsonFilePath))
            {
                Console.Out.WriteLine($"{_jsonFilePath} not found");
                return new List<Logs>();
            }

            var json = await File.ReadAllTextAsync(_jsonFilePath);
            return JsonSerializer.Deserialize<List<Logs>>(json) ?? new List<Logs>();

        }

        public async Task<int> getNbLogs()
        {
            throw new NotImplementedException();
        }

        public async Task<List<Logs>> getSomeLogs(int nb, int page)
        {
            var logs = await getAllLogs();
            if ((page - 1) * nb + nb > logs.Count())
            {
                return logs.GetRange(logs.Count() - nb, nb);
            }
            return logs.GetRange((page - 1) * nb, nb);

        }

        public async Task removeLogs(Logs logs)
        {
            var data = await getAllLogs();
            var l = data.FirstOrDefault(p => p.Message ==logs.Message && p.LogLevel==logs.LogLevel);
            if (l != null)
            {
                data.Remove(l);
                await saveLogsJson(data);
            }
        }
    }
}
